Log Master v2.4-SE — File Browser

LogMaster-SEv2.4 / LogMaster-SEv2.4 / logmastr.mrc

logmastr.mrc — 15.93 KB — Download this file

;======================================================
;        Log Master v2.4 Addon For mIRC 5.31+
;            by Paul <kbhw@religious.com>           
;======================================================
on 1:LOAD:{
  if ($version <= 5.3) echo -a 4,1 You need mIRC 5.3 or higher to use Log Master v2.2!! 
  else {
    set %logmaster.version v2.4
    set %logmaster.about run
    echo -a 4,1 Log Master v2.4-SE installed! - Use The Popups In The Status/Channel Windows or type /logmaster to run. 
  }
}
alias logmaster.about {
  if ($window(@LogMaster) == $null) { set %logmaster.about run | logmaster }
  else {
    clear @LogMaster
    titlebar @LogMaster - About
    window @LogMaster @LogMaster
    aline @LogMaster 4,1 Log Master %logmaster.version  $str($chr(160),76) 8,1By Paul <kbhw@religious.com> $str($chr(160),100)
    aline @LogMaster $chr(160)
    aline -p @LogMaster $str($chr(160),4) Thank you for installing the Log Master addon.  Log Master allows you to manage your IRC logs quickly and easily.  You now do not have to open up notepad to view every single log anymore.  With Log Master, you can open each log in full color right in mIRC!  Besides opening logs in mIRC, you may open them in notepad, search a log for certain text, rename logs, delete logs, and copy logs to a different directory.  mIRC v5.31 has allowed many more enhancements to the interface, and has allowed me to add more commands to this version of Log Master.
    aline @LogMaster $chr(160)
    aline @LogMaster $chr(160) 4Changes In  Version %logmaster.version $+ :
    aline -p @LogMaster $str($chr(160),4) o Added the Refresh Log and Goto commands. 
    aline -p @LogMaster $str($chr(160),4) o Made Popups Dynamic.
    aline -p @LogMaster $str($chr(160),4) o Re-Organized Popups to make them compact.
    aline -p @LogMaster $str($chr(160),4) o Fixed some small bugs.
    aline -p @LogMaster $str($chr(160),4) o Added log lines to the log stats when you view a log.
    aline @LogMaster $chr(160)
    aline -p @LogMaster $str($chr(160),4) Once Again, thank you for using Log Master %logmaster.version $+ !! If you have any comments, suggestions, bug reports, or questions, please e-mail them to: 4kbhw@religious.com.
    aline @LogMaster $chr(160)
  }
} 
alias logmaster.help {
  if ($window(@LogMaster) == $null) { halt }
  else {
    clear @LogMaster
    titlebar @LogMaster - Help
    window @LogMaster @LogMaster
    aline @LogMaster 4,1 Log Master %logmaster.version  $str($chr(160),76) 8,1By Paul <kbhw@religious.com> $str($chr(160),100)
    aline @LogMaster $chr(160)
    aline -p @LogMaster $str($chr(160),4) This version of Log Master is easier to use than ever!  To view a log, just double click on it in the list that is on the right of your screen.  To do other commands like copying logs, renaming logs, opening logs in notepad, and searching for text in logs, right click on a log in the list on the right.  It's that simple!
    aline @LogMaster $chr(160)
  }
} 
alias logmaster {
  :start
  if ($window(@LogMaster) == $null) {  
    window -l16x @LogMaster @LogMaster Arial 11
    window -nls @LogMaster2 Arial 11
    set %logmaster.count 1
    :AddLog
    set %logmaster.log $findfile($logdir,*.log,%logmaster.count)
    if (%logmaster.log == $null) goto end
    else {
      aline -l @LogMaster2 $nopath(%logmaster.log)
      inc %logmaster.count 1
    goto addlog }
  }
  else { window -c @Logmaster | goto start }
  :end
  set %logmaster.lines $line(@LogMaster2,0,0)
  set %logmaster.count 1
  :lineadd
  if (%logmaster.count > %logmaster.lines) goto end2
  else {
    aline -l @LogMaster $line(@LogMaster2,%logmaster.count)
    inc %logmaster.count 1
    goto lineadd
  }
  :end2
  if (%logmaster.about == run) { logmaster.about | set %logmaster.about ran | goto end3 }
  aline @LogMaster 4,1 Log Master %logmaster.version  $str($chr(160),76) 8,1By Paul <kbhw@religious.com> $str($chr(160),100)
  aline @LogMaster $chr(160)
  aline -p @LogMaster $str($chr(160),4) Welcome To Log Master %logmaster.version $+ !  To view a log, please double click it in the side listbox.  You may also right click on a log in the listbox to access more commands.
  :end3
  iline -l @LogMaster 1 4,1 $chr(160) Log Master %logmaster.version  $str($chr(160),15)
  iline -l @LogMaster 2 8,1 ————————————————— $str($chr(160),175)
  window -c @LogMaster2
}
alias logrefresh {
  :start
  if ($window(@LogMaster) == $null) { logmaster }
  else {
    clear -l @LogMaster
    window -nls @LogMaster2 Arial 11
    set %logmaster.count 1
    :AddLog
    set %logmaster.log $findfile($logdir,*.log,%logmaster.count)
    if (%logmaster.log == $null) goto end
    else {
      aline -l @LogMaster2 $nopath(%logmaster.log)
      inc %logmaster.count 1
    goto addlog }
  }
  :end
  set %logmaster.lines $line(@LogMaster2,0,0)
  set %logmaster.count 1
  :lineadd
  if (%logmaster.count > %logmaster.lines) goto end2
  else {
    aline -l @LogMaster $line(@LogMaster2,%logmaster.count)
    inc %logmaster.count 1
    goto lineadd
  }
  :end2
  iline -l @LogMaster 1 4,1 $chr(160) Log Master %logmaster.version  $str($chr(160),15)
  iline -l @LogMaster 2 8,1 ————————————————— $str($chr(160),175)
  window -c @LogMaster2
}
alias Logview {
  if ($2 == $null) {
    if ($sline(@LogMaster,1).ln == 1 || $sline(@LogMaster,1).ln == 2 || $sline(@LogMaster,1).ln == $null) { halt }
    else {
      set %logmaster.file $logdir $+ $sline(@LogMaster,1)
      clear @LogMaster    
      iline @LogMaster 1 8,1 Log Master %logmaster.version $str($chr(160),15) 4,1 Viewing: $sline(@LogMaster,1) ( $+ $lof(%logmaster.file) bytes - $lines(%logmaster.file) lines) $str($chr(160),175)
      titlebar @LogMaster - $sline(@LogMaster,1)
      loadbuf -p @LogMaster $logdir $+ $sline(@LogMaster,1)
      aline @LogMaster 4,1 Successfully Loaded $calc($line(@LogMaster,0) - 1) of $lines(%logmaster.file) lines. $str($chr(160),175)
      sline @LogMaster 15 
      window @LogMaster @LogMaster2
    }
  }
  else {
    set %logmaster.file $logdir $+ $2
    clear @LogMaster    
    iline @LogMaster 1 8,1 Log Master %logmaster.version $str($chr(160),15) 4,1 Viewing: $2 ( $+ $lof(%logmaster.file) bytes - $lines(%logmaster.file) lines) $str($chr(160),175)
    titlebar @LogMaster - $2
    loadbuf -p @LogMaster $logdir $+ $2
    sline @LogMaster 15
    window @LogMaster @LogMaster2
  }
}
alias logview.newwindow {
  if ($2 == $null) {
    if ($sline(@LogMaster,1).ln == 1 || $sline(@LogMaster,1).ln == 2 || $sline(@LogMaster,1).ln == $null) { halt }
    else {
      set %logmaster.window @ [ $+ [ $sline(@LogMaster,1) ] ]
      set %logmaster.file $logdir $+ $sline(@LogMaster,1)
      window -x %logmaster.window @LogView Arial 11
      iline %logmaster.window 1 8,1 Log Master %logmaster.version $str($chr(160),15) 4,1 Viewing: $sline(@LogMaster,1) ( $+ $lof(%logmaster.file) bytes - $lines(%logmaster.file) lines) $str($chr(160),175)
      loadbuf -p %logmaster.window $logdir $+ $sline(@LogMaster,1)
      aline %logmaster.window 4,1 Successfully Loaded $calc($line(%logmaster.window,0) - 1) of $lines(%logmaster.file) lines. $str($chr(160),175)
      sline %logmaster.window 15 
    }
  }
  else {
    set %logmaster.window @ [ $+ [ $2 ] ]
    set %logmaster.file $logdir $+ $2
    window -x %logmaster.window @LogView Arial 11
    iline %logmaster.window 1 8,1 Log Master %logmaster.version $str($chr(160),15) 4,1 Viewing: $2 ( $+ $lof(%logmaster.file) bytes - $lines(%logmaster.file) lines) $str($chr(160),175)
    loadbuf -p %logmaster.window $logdir $+ $2
    aline %logmaster.window 4,1 Successfully Loaded $calc($line(%logmaster.window,0) - 1) of $lines(%logmaster.file) lines. $str($chr(160),175)
    sline %logmaster.window 15 
  }
}
menu Status {
  Log Master %logmaster.version:logmaster
}
menu Channel {
  Log Master %logmaster.version:logmaster
}
menu Menubar {
  Log Master %logmaster.version:logmaster
}
menu @LogMaster {
  dclick loglist2
  View Log
  .In Window:logview
  .In New Window:logview.newwindow
  .In Notepad:lognotepad
  Search Log:logsearch
  -
  Manage Logs
  .Delete Log:dellog $sline(@LogMaster,1)
  .Copy Log:copylog
  .Rename Log:remlog
  -
  Refresh List:logrefresh
  Close Window:window -c @LogMaster
  -
  Help:logmaster.help
  About:logmaster.about
}
menu @LogMaster2 {
  dclick loglist2
  View Log
  .In Window:logview
  .In New Window:logview.newwindow
  .In Notepad:lognotepad
  Search Log:logsearch
  Refresh Log:lrefresh
  Goto
  .Beginning:sline @LogMaster 15
  .End:sline @LogMaster $line(@LogMaster,0)
  .-
  .Line:sline @LogMaster $?="Please Enter a Line Number"
  -
  Manage Logs
  .Delete Log:dellog $sline(@LogMaster,1)
  .Copy Log:copylog
  .Rename Log:remlog
  -
  Refresh List:logrefresh
  Close Window:window -c @LogMaster
  -
  Help:logmaster.help
  About:logmaster.about
}
alias lrefresh {
  if (($window(@Logmaster).title == - Help) || ($window(@Logmaster).title == - About)) { halt }
  else {
    set %logmaster.title $window(@Logmaster).title
    set %logmaster.title.2 $len(%logmaster.title)
    set %logmaster.title $mid(%logmaster.title,3,%logmaster.title.2)
    logview %logmaster.title
  }
}
alias LogList2 {
  if ($sline(@LogMaster,1).ln == 1 || $sline(@LogMaster,1).ln == 2 || $sline(@LogMaster,1).ln == $null) { halt }
  else logview $sline(@LogMaster,1)
}
menu @Logview {
  View Log
  .In Notepad:run notepad.exe $logdir $+ $remove($active,@)
  Search Log:logsearch.nw
  Refresh Log:clear $active | logview.newwindow $remove($active,@)
  Goto
  .Beginning:sline $active 15
  .End:sline $active $line($active,0)
  .-
  .Line:sline $active $?="Please Enter a Line Number"
  
  -
  Close Window:window -c $active
  -
  Help:window -a @LogMaster | logmaster.help
  About:window -a @LogMaster | logmaster.about
}
menu @Confirm.Delete {
  dclick Confirm.Delete
}
alias Confirm.Delete {
  if ($sline(@Confirm.Delete,1).ln == 1 || $sline(@Confirm.Delete,1).ln == 2 || $sline(@Confirm.Delete,1).ln == 3 || $sline(@Confirm.Delete,1).ln == 4) { halt }
  if ($sline(@Confirm.Delete,1).ln == 5) { remove $logdir $+ %logmaster.log.delete | window -c @Confirm.Delete | dline -l @LogMaster $sline(@LogMaster,1).ln | echo 1,1.8,1Log Master %logmaster.version -4,1 %logmaster.log.delete DELETED!1,1. }
  if ($sline(@Confirm.Delete,1).ln == 6) { window -c @Confirm.Delete }
}
alias copylog {
  if ($sline(@LogMaster,1).ln == 1 || $sline(@LogMaster,1).ln == 2 || $sline(@LogMaster,1).ln == $null) { halt }
  /copy $logdir $+ $sline(@LogMaster,1) $sdir="Select A Directory To Copy $sline(@LogMaster,1) To:" $+ $sline(@LogMaster,1)
}
alias remlog {
  if ($sline(@LogMaster,1).ln == 1 || $sline(@LogMaster,1).ln == 2 || $sline(@LogMaster,1).ln == $null) { halt }
  else {
    set %logmaster.newname $?="Please Enter A New File Name:"
    if (%logmaster.newname == $null) { halt }
    else {
      rename $logdir $+ $sline(@LogMaster,1) $logdir $+ %logmaster.newname
      logrefresh
    }
  }
}
alias dellog {
  if ($sline(@LogMaster,1).ln == 1 || $sline(@LogMaster,1).ln == 2 || $sline(@LogMaster,1).ln == $null) { halt } 
  else {
    set %logmaster.log.delete $sline(@LogMaster,1)
    window -l @Confirm.Delete 20 20 150 111 @Confirm.Delete Arial 11
    aline @Confirm.Delete 8,1 Are you sure you want $str($chr(160),10)
    aline @Confirm.Delete 8,1 to delete: $str($chr(160),50)
    aline @Confirm.Delete 8,1 $sline(@LogMaster,1) $+ ? $str($chr(160),100)
    aline @Confirm.Delete 8,1 ------------------------------------ $str($chr(160),10)
    aline @Confirm.Delete 4,1 YES $str($chr(160),50)
    aline @Confirm.Delete 4,1 NO $str($chr(160),50)
  }
}
alias dellog2 {
  set %logmaster.log.delete $remove($active,@)
  window -l @Confirm.Delete 20 20 150 111 @Confirm.Delete2 Arial 11
  aline @Confirm.Delete 8,1 Are you sure you want $str($chr(160),10)
  aline @Confirm.Delete 8,1 to delete: $str($chr(160),50)
  aline @Confirm.Delete 8,1 %logmaster.log.delete $+ ? $str($chr(160),100)
  aline @Confirm.Delete 8,1 ------------------------------------ $str($chr(160),10)
  aline @Confirm.Delete 4,1 YES $str($chr(160),50)
  aline @Confirm.Delete 4,1 NO $str($chr(160),50)
}
menu @Confirm.Delete2 {
  dclick Confirm.Delete2
}
alias Confirm.Delete2 {
  if ($sline(@Confirm.Delete,1).ln == 1 || $sline(@Confirm.Delete,1).ln == 2 || $sline(@Confirm.Delete,1).ln == 3 || $sline(@Confirm.Delete,1).ln == 4) { halt }
  if ($sline(@Confirm.Delete,1).ln == 5) { remove $logdir $+ %logmaster.log.delete | window -c @Confirm.Delete | logrefresh | echo 1,1.8,1Log Master %logmaster.version -4,1 %logmaster.log.delete DELETED!1,1. }
  if ($sline(@Confirm.Delete,1).ln == 6) { window -c @Confirm.Delete }
}
alias lognotepad {
  if ($sline(@LogMaster,1).ln == 1 || $sline(@LogMaster,1).ln == 2 || $sline(@LogMaster,1).ln == $null) { halt }
  else run notepad.exe $logdir $+ $sline(@LogMaster,1)
}
alias logsearch {
  if ($sline(@LogMaster,1).ln == 1 || $sline(@LogMaster,1).ln == 2 || $sline(@LogMaster,1).ln == $null) { halt }
  if ($window(@Logmaster).title == - $sline(@LogMaster,1)) goto next
  else { logview $sline(@LogMaster,1) | goto next }
  :next
  if ($window(@LogSearch) != $null) /window -c @LogSearch
  window -lx @LogSearch @LogSearch Arial 11
  set %logmaster.file $logdir $+ $sline(@LogMaster,1)
  set %logmaster.log $sline(@LogMaster,1)
  titlebar @LogSearch - %logmaster.log
  set %logmaster.searchstring * [ $+ [ $?="Enter Text To Search For:" ] $+ ] *
  if ($! == $null) { 
    aline @LogSearch 4,1 Log Master %logmaster.version  $str($chr(160),150) 8,1Log Searcher $str($chr(160),100)
    aline @LogSearch 8,1 $str($chr(160),20) Searching %logmaster.log For:4,1 Nothing (User Pressed Cancel) $str($chr(160),500)
  }
  else {
    aline @LogSearch 4,1 Log Master %logmaster.version  $str($chr(160),150) 8,1Log Searcher $str($chr(160),100)
    aline @LogSearch 8,1 $str($chr(160),20) Searching %logmaster.log For:4,1 %logmaster.searchstring  $str($chr(160),500)
    filter -fwn %logmaster.file @LogSearch %logmaster.searchstring
    aline @LogSearch 4,1 Found $calc($line(@LogSearch,0) - 2) occurances of %logmaster.searchstring in %logmaster.log $str($chr(160),500) 
  }
}
menu @LogSearch {
  dclick logsearch2
  Goto Line:logsearch2
  -
  Close Window:window -c @LogSearch
  -
  Help:window -a @LogMaster | logmaster.help
  About:window -a @LogMaster | logmaster.about
} 
alias logsearch2 {
  if ($sline(@LogSearch,1).ln == 1 || $sline(@LogLogSearch,1).ln == 2 || $sline(@LogSearch,1).ln == $null) { halt }
  else {
    sline @LogMaster $calc($gettok($sline(@LogSearch,1),1,32) + 10)
    window -a @LogMaster
  }
}
alias logsearch.nw {
  set %logmaster.window $remove($active,@)
  if ($window(@LogSearch) != $null) window -c @LogSearch
  window -lx @LogSearch @LogSearch.nw Arial 11
  set %logmaster.file $logdir $+ %logmaster.window
  titlebar @LogSearch - %logmaster.window
  set %logmaster.searchstring * [ $+ [ $?="Enter Text To Search For:" ] $+ ] *
  aline @LogSearch 4,1 Log Master %logmaster.version  $str($chr(160),150) 8,1Log Searcher $str($chr(160),100)
  aline @LogSearch 8,1 $str($chr(160),20) Searching For:4,1 %logmaster.searchstring  $str($chr(160),500)
  filter -fwn %logmaster.file @LogSearch %logmaster.searchstring
  aline @LogSearch 4,1 Found $calc($line(@LogSearch,0) - 2) occurances of %logmaster.searchstring in %logmaster.window $str($chr(160),500) 
}
menu @LogSearch.nw {
  dclick:logsearchnw
  Goto Line:logsearchnw
  -
  Close Window:window -c @LogSearch
  Help:window -a @LogMaster | logmaster.help
  About:window -a @LogMaster | logmaster.about
} 
alias logsearchnw {
  if ($sline(@LogSearch,1).ln == 1 || $sline(@LogSearch,1).ln == 2 || $sline(@LogSearch,1).ln == $null) { halt }
  else {
    set %logmaster.window2 @ $+ %logmaster.window
    sline %logmaster.window2 $calc($gettok($sline(@LogSearch,1),1,32) + 10)
    window -a %logmaster.window2
  }
}